==> haskell-process-extras-0.7.4-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-1x5l4fenlTjDgKlgTpND4q
key:                  process-extras-0.7.4-1x5l4fenlTjDgKlgTpND4q
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  ba1a803e5c1439c1135d404ed26c1ccb
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-8.8.3/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/process-extras-0.7.4
hs-libraries:         HSprocess-extras-0.7.4-1x5l4fenlTjDgKlgTpND4q
depends:
    ListLike-4.6.3-Gymq56ugC4GK0fdOmuZv5D base-4.13.0.0
    bytestring-0.10.10.0 data-default-0.7.1.1-EftUPu9UviH5yKWklJYX5z
    deepseq-1.4.4.0 generic-deriving-1.13.1-92moKBcJsaNFDvUoaiNUgX
    mtl-2.2.2 process-1.6.8.0 text-1.2.4.0

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-process-extras-0.7.4-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-process-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 process-extras
version:              0.7.4
visibility:           public
id:                   process-extras-0.7.4-5SowVmwHmw2L5IILZxVlU4
key:                  process-extras-0.7.4-5SowVmwHmw2L5IILZxVlU4
license:              MIT
maintainer:           David Fox <dsf@seereason.com>
author:               David Lazar, Bas van Dijk, David Fox
homepage:             https://github.com/seereason/process-extras
synopsis:             Process extras
description:
    Extends <http://hackage.haskell.org/package/process>.
    Read process input and output as ByteStrings or
    Text, or write your own ProcessOutput instance.
    Lazy process input and output.  ProcessMaker class
    for more flexibility in the process creation API.

category:             System
abi:                  82ef4b75197d9d5dc974c10bc48e34f5
exposed:              True
exposed-modules:
    System.Process.ByteString System.Process.ByteString.Lazy
    System.Process.Chars System.Process.Common System.Process.ListLike
    System.Process.Run System.Process.Text System.Process.Text.Builder
    System.Process.Text.Lazy

hidden-modules:       Utils
import-dirs:          /usr/lib/ghc-8.8.3/site-local/process-extras-0.7.4
library-dirs:         /usr/lib/ghc-8.8.3/site-local/process-extras-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/process-extras-0.7.4
hs-libraries:         HSprocess-extras-0.7.4-5SowVmwHmw2L5IILZxVlU4
depends:
    ListLike-4.6.3-H4UBOkDWLDC9ixvK2sdeF0 base-4.13.0.0
    bytestring-0.10.10.0 data-default-0.7.1.1-I8r7Cbmq1E6LZFNWImh508
    deepseq-1.4.4.0 generic-deriving-1.13.1-4vpMv34ltDW362VEdObQ5i
    mtl-2.2.2 process-1.6.8.0 text-1.2.4.0

haddock-interfaces:
    /usr/share/doc/haskell-process-extras/html/process-extras.haddock

haddock-html:         /usr/share/doc/haskell-process-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
